@@ -135,6 +135,12 @@ so that the other paths have suitable values.""")
             default='%(master_dir)s/media',
             help='Path to folder of static media.')
 
+        parser.add_option(
+            '--wsgi-file',
+            dest='wsgiFile',
+            default='%(master_dir)s/wsgi/'+self.systemName+'.wsgi',
+            help='Path to the auto-generated WSGI file.')
+
 
     def addOptionLines(self, options, optionLines):
         optionLines.append('[DEFAULT]')
@@ -202,6 +208,8 @@ so that the other paths have suitable values.""")
                 optionLines.append('apache_config_file = %s' % options.apacheConfigFile)
             if options.mediaDir:
                 optionLines.append('media_dir = %s' % options.mediaDir)
+            if options.wsgiFile:
+                optionLines.append('wsgi_file = %s' % options.wsgiFile)
 
         
     def generateNewSecretKey(self):
