@@ -71,7 +71,7 @@ class DomainObjectCommand(Command):
 
     def __init__(self, typeName=None, objectId=None, objectKwds={}, **kwds):
         super(DomainObjectCommand, self).__init__(**kwds)
-        if not typeName: 
+        if not typeName:
             raise KforgeCommandError("No typeName parameter for %s" % str(self))
         self.typeName = typeName
         self.objectId = objectId
@@ -88,7 +88,7 @@ class DomainObjectCommand(Command):
     def createRegister(self):
         self.assertDomainClassRegistered()
         objectClass = self.getDomainClass()
-        return objectClass.createRegister()
+        return objectClass.principalRegister or objectClass.createRegister()
 
 # todo: rename following <Action>DomainObject (e.g. "Create [a] domain object!")
 
