@@ -62,7 +62,7 @@ import dm.dom.meta
 import sqlobject.main
 from dm.ioc import *
 from dm.dictionarywords import *
-import mx.DateTime
+import datetime
 import weakref
 
 debug = RequiredFeature('Debug')
@@ -894,11 +894,9 @@ class Mapper(SQLObject):
             elif metaAttr.dom.isValueRef and metaAttr.dom.isDateTime:
                 mappedValue = getattr(self, dbName)
                 if (mappedValue != None) and (mappedValue != ''):
-                    # Coerse to DateTime.
+                    # Coerse to datetime.
                     # todo: stabilise SQLObject's date-time choice
-                    # That strange behaviour seems to be a symptom of having
-                    # different mx.DateTime packages installed and available.
-                    mappedValue = mx.DateTime.DateTime(
+                    mappedValue = datetime.datetime(
                         mappedValue.year,
                         mappedValue.month,
                         mappedValue.day,
@@ -927,7 +925,6 @@ class Mapper(SQLObject):
             currentVersion = self.domainObject().temporalHistory.getCurrent()
             if not currentVersion:
                 isChangedTemporal = True
-
             if not isChangedTemporal:
                 for metaAttr in self.domainObject().meta.attributes:
                     if metaAttr.isTemporal:
