@@ -48,6 +48,7 @@ class SystemDictionary(dict):
     def setDefaultWords(self):
         self[PYTHONPATH]          = '' #os.environ.get('PYTHONPATH', '')
         self[SYSTEM_NAME]         = self.getSystemName()
+        self[SYSTEM_TITLE]        = self.getSystemTitle()
         self[SYSTEM_PACKAGE_NAME] = self.getSystemPackageName()
         self[SYSTEM_SERVICE_NAME] = self.getSystemServiceName()
         self[SYSTEM_MODE]         = 'production'
@@ -66,6 +67,7 @@ class SystemDictionary(dict):
         self[APACHE_RELOAD_CMD]   = '' #'sudo /etc/init.d/apache2 reload'
         self[SKIP_APACHE_RELOAD]  = ''
         self[APACHE_CONFIGTEST_CMD] = '' #'sudo /etc/init.d/apache2 configtest'
+        self[WSGI_SCRIPT_PATH]    = ''
         self[DOMAIN_NAME]         = self.getDomainName()
         self[HTTP_PORT]           = '80'
         self[HTTPS_PORT]          = '443'
@@ -228,6 +230,14 @@ class SystemDictionary(dict):
     def getSystemVersion(self):
         return dm.__version__
 
+    def getSystemTitle(self):
+        systemName = self[SYSTEM_NAME]
+        if systemName == 'domainmodel':
+            systemTitle = 'DomainModel'
+        else:
+            systemTitle = systemName.capitalize()
+        return systemTitle
+
     def getSystemName(self):
         return 'domainmodel'
 
