@@ -1,8 +1,8 @@
+import unittest
+import dm.times
 import dm.dictionary
 from dm.dictionarywords import *
-import unittest
 import os
-import mx.DateTime
 
 def suite():
     suites = [
@@ -25,5 +25,5 @@ class TestSystemDictionary(unittest.TestCase):
     def test_systemUpSince(self):
         upSince = self.dictionary[SYSTEM_UP_SINCE]
         self.failUnless(upSince)
-        self.failUnless(upSince < mx.DateTime.now())
+        self.failUnless(upSince < dm.times.getUniversalNow())
 
