@@ -1,4 +1,5 @@
 SYSTEM_NAME = 'system_name'
+SYSTEM_TITLE = 'system_title'
 SYSTEM_MODE = 'system_mode'
 SYSTEM_VERSION = 'system_version'
 SYSTEM_PACKAGE_NAME = 'system_package_name'
@@ -35,6 +36,7 @@ AUTH_COOKIE_NAME = 'auth_cookie_name'
 NO_AUTH_COOKIE_NAME = 'no_auth_cookie_name'
 AUTH_COOKIE_DOMAIN = 'auth_cookie_domain'
 APACHE_CONFIG_PATH = 'www.apache_config_file'
+WSGI_SCRIPT_PATH = 'www.wsgi_file'
 SKIP_APACHE_RELOAD = 'www.no_reload_apache'
 APACHE_RELOAD_CMD = 'www.reload_apache'
 APACHE_CONFIGTEST_CMD = 'www.apache_configtest'
