@@ -218,19 +218,17 @@ class DomainObjectRegister(AbstractRegister):
     
     def keys(self, **kwds):
         "Returns list of keys for register."
-        self.coerceKwds(kwds)
-        self.switchToRecords(kwds)
-        keys = []
-        results = self.database.listRecords(self.typeName, **kwds)
+        values = self.values(**kwds)
         keyName = self.getKeyName()
-        for record in results:
-            key = getattr(record.getDomainObject(), keyName)
-            keys.append(key)
-        return keys
+        return [self.getRegisterKey(v) for v in values]
 
     def values(self, **kwds):
         "Returns list of records of register."
-        self.getObjectList()
+        self.coerceKwds(kwds)
+        self.switchToRecords(kwds)
+        values = []
+        results = self.database.listRecords(self.typeName, **kwds)
+        return [r.getDomainObject() for r in results]
 
     def startsWith(self, value, attributeName=''):
         kwds = {}
@@ -263,19 +261,26 @@ class DomainObjectRegister(AbstractRegister):
     
     def createDomainObject(self, *args, **kwds):
         try:
+            temporalKwds = {}
+            for metaAttr in self.getDomainClassMetaAttributes():
+                if metaAttr.isTemporal and metaAttr.name in kwds:
+                    temporalKwds[metaAttr.name] = kwds.pop(metaAttr.name)
             self.coerceArgs(args, kwds)
             self.initialiseKwds(kwds)
             self.initialiseWithDefaults(kwds)
             self.coerceKwds(kwds)
             self.switchToRecords(kwds)
-            object = self.database.createDomainObject(self.typeName, **kwds)
-            self.initialiseObject(object)
-            if object.isChanged:
-                object.save()
+            domainObject = self.database.createDomainObject(self.typeName, **kwds)
+            for (attrName, attrValue) in temporalKwds.items():
+                setattr(domainObject, attrName, attrValue)
+                domainObject.isChanged = True
+            self.initialiseObject(domainObject)
+            if domainObject.isChanged:
+                domainObject.save()
         except KforgeDbError, inst:
             raise KforgeDomError(inst)
         else:
-            return object
+            return domainObject
 
     def findDomainObject(self, key):
         "Finds existing object."
@@ -704,6 +709,9 @@ class DomainObject(DomainBase):
     def initialise(self, register=None):
         pass 
     
+    def isActionActionable(self, actionName):
+        return True
+
     def save(self):
         "Update record of object in the database."
         self.saveSilently()
