@@ -6,6 +6,7 @@ from dm.exceptions import *
 def suite():
     suites = [
         unittest.makeSuite(TestPerson),
+        unittest.makeSuite(TestPersonFilter),
     ]
     return unittest.TestSuite(suites)
 
@@ -159,4 +160,43 @@ class TestPerson(TestCase):
         self.failUnlessEqual(previousPerson, personList[0])
         previousPerson = self.persons.getPreviousObject(personList, previousPerson)
         self.failIf(previousPerson)
- 
+
+    def test_getOptionsRegister(self):
+        # HasMany
+        optionsRegister = self.person.grants.getOptionsRegister()
+        optionsClassName = optionsRegister.getDomainClassMeta().name
+        self.failUnlessEqual(optionsClassName, 'Permission')
+        # HasA
+        optionsRegister = self.person.getOptionsRegister('role')
+        optionsClassName = optionsRegister.getDomainClassMeta().name
+        self.failUnlessEqual(optionsClassName, 'Role')
+
+
+class TestPersonFilter(TestCase):
+    "TestCase for the Person class, with filter."
+    
+    def setUp(self):
+        super(TestPersonFilter, self).setUp()
+        self.fixtureName = 'TestPerson'
+        self.persons = self.registry.persons
+        allPersons = self.persons.getAll()
+        if self.fixtureName in allPersons:
+            person = allPersons[self.fixtureName]
+            person.delete()
+            person.purge()
+        self.person = self.persons.create(self.fixtureName)
+
+    def tearDown(self):
+        if self.person:
+            self.person.delete()
+            self.person.purge()
+        super(TestPersonFilter, self).tearDown()
+
+    def test_filter(self):
+        self.persons.filter = {'name': self.fixtureName}
+        self.failUnlessEqual(len(self.persons), 1)
+        self.persons.filter = {'name': 'NotaName'}
+        self.failUnlessEqual(len(self.persons), 0)
+        self.persons.filter = {}
+   
+
