@@ -40,7 +40,7 @@ def initLogging():
         'ERROR'    : logging.ERROR,
         'CRITICAL' : logging.CRITICAL
     }
-    logLevelName = dictionary[LOG_LEVEL]
+    logLevelName = dictionary[LOG_LEVEL].upper()
     if logLevelName in logLevels:
         logLevel = logLevels[logLevelName]
     elif logLevelName:
@@ -81,5 +81,5 @@ def initLogging():
     
 initLogging()
 log = getLogger()
-log.warning('Logging initialised.')
+log.info('Logger: Logging initialised.')
 
