@@ -465,8 +465,8 @@ class DomainModelMigrator(BaseStrategy):
                         from dm.datetimeconvertor import DateTimeConvertor
                         dateTimeConvertor = DateTimeConvertor()
                         dateTime = dateTimeConvertor.fromHTML(dateTimeString)
-                        import mx.DateTime
-                        date = mx.DateTime.Date(
+                        import datetime
+                        date = datetime.date(
                             dateTime.year, dateTime.month, dateTime.day
                         )
                         from dm.datetimeconvertor import DateConvertor
