@@ -77,8 +77,8 @@ class TestDomainModelLoader(TestCase):
         self.failUnless('migrated' in self.registry.persons)
         self.failUnlessEqual(self.registry.persons['migrated'].fullname, "Unicode \xc3\xb3 Jeff".decode('utf8'))
         self.failUnless('migrated2' in self.registry.persons)
-        import mx.DateTime
-        self.failUnlessEqual(self.registry.persons['migrated2'].dateCreated, mx.DateTime.DateTime(2005,12,31,18,30,0))
+        import datetime
+        self.failUnlessEqual(self.registry.persons['migrated2'].dateCreated, datetime.datetime(2005,12,31,18,30,0))
         del(self.registry.persons['migrated'])
         del(self.registry.persons['migrated2'])
         self.failIf('migrated' in self.registry.persons)
