@@ -10,6 +10,7 @@ import dm.domtest
 import dm.plugintest
 import dm.ioctest
 import dm.configtest
+import dm.configwritertest
 import dm.dictionarytest
 import dm.commandtest
 import dm.filesystemtest
@@ -36,6 +37,7 @@ def suite():
         dm.plugintest.suite(),
         dm.ioctest.suite(),
         dm.configtest.suite(),
+        dm.configwritertest.suite(),
         dm.dictionarytest.suite(),
         dm.commandtest.suite(),
         dm.accesscontroltest.suite(),
