@@ -12,10 +12,10 @@ from dm.util.datastructure import MultiValueDict
 from dm.webkit import HttpResponse
 from dm.webkit import HttpResponseRedirect
 from dm.webkit import Context
+from dm.webkit import RequestContext
 from dm.webkit import template_loader
 import dm.times
 import os
-import mx.DateTime
 
 moddebug = False
 
@@ -406,8 +406,9 @@ class SessionView(ControlledAccessView):
         self.project = None
         self.member = None
         self.service = None
-        self.handlingStarted = mx.DateTime.now()
+        self.handlingStarted = dm.times.getLocalNow()
         self.readRequest()
+        self.requiresCsrfToken = bool(RequestContext)
 
     def __repr__(self):
         return "<%s redirect='%s' redirectPath='%s'>" % (
@@ -512,7 +513,10 @@ class SessionView(ControlledAccessView):
     def createContext(self):
         webkitName = self.dictionary[WEBKIT_NAME]
         if webkitName == 'django':
-            self.context = Context()
+            if RequestContext:
+                self.context = RequestContext(self.request)
+            else:
+                self.context = Context()
     
     def markNavigation(self):
         self.markMajorNavigation()
@@ -655,12 +659,9 @@ class SessionView(ControlledAccessView):
             systemMediaSocket = mediaHost +":"+ mediaPort
         else:
             systemMediaSocket = mediaHost
-       
-        pageCreated = dm.times.getLocalNowCWithZone()
         localNow = dm.times.getLocalNow()
-        
         self.context.update({
-            'pageCreated'       : pageCreated,
+            'pageCreated'       : localNow.strftime('%c'),
             'localNow'          : localNow,
             'view'              : self,
             'uriPrefix'         : self.dictionary[URI_PREFIX],
@@ -787,7 +788,7 @@ class SessionView(ControlledAccessView):
         msg +=" domainmodel==%s" % (dm.__version__)
         msg +=" %s==%s" % (dm.webkit.webkitName, dm.webkit.webkitVersionFull or dm.webkit.webkitVersion)
         msg +=" sqlobject==%s" % (dm.db.sqoVer)
-        msg +=" (%ss)" % str(float(mx.DateTime.now() - self.handlingStarted))[0:5]
+        msg +=" (%ss)" % (dm.times.getLocalNow() - self.handlingStarted).seconds
         return msg
 
 class AbstractClassView(SessionView):
@@ -887,7 +888,10 @@ class AbstractFormView(AbstractInstanceView):
                 self.logger.warning("%s: Form errors: %s" % (
                     self.__class__.__name__, self.formErrors
                 ))
-        elif not self.getRequestParams():
+        elif self.getRequestParams():
+            # Initialise the form fields with request params.
+            self.getValidationErrors()
+        else:
             self.requestParams = self.getInitialParams()
             self.formErrors = self.getZeroFormErrors() 
                 
