@@ -8,12 +8,13 @@ from dm.util.datastructure import MultiValueDict
 def suite():
     suites = [
         unittest.makeSuite(TestDomainObjectManipulator),
-#        unittest.makeSuite(TestDomainObjectManipulatorCreate),
-#        unittest.makeSuite(TestDomainObjectManipulatorUpdate),
-#        unittest.makeSuite(TestHasManyManipulator),
+        unittest.makeSuite(TestDomainObjectManipulatorCreate),
+        unittest.makeSuite(TestDomainObjectManipulatorUpdate),
+        unittest.makeSuite(TestHasManyManipulator),
     ]
     return unittest.TestSuite(suites)
 
+# Todo: Test for manipulator building fields for attr types: Text (ie Textarea), Integer, Date, Markdown, Url, Boolean, Image, default, and HasA when choices > 50. 
 
 class ManipulatorTestCase(TestCase):
 
@@ -36,6 +37,7 @@ class ManipulatorTestCase(TestCase):
 class DomainObjectManipulatorTestCase(ManipulatorTestCase):
 
     fixtureName = 'DomainObjectManipulatorTestCase'
+    sessionKey = 'sessiontestkey34234234234535634561345'
 
     def setUp(self):
         super(DomainObjectManipulatorTestCase, self).setUp()
@@ -49,9 +51,12 @@ class DomainObjectManipulatorTestCase(ManipulatorTestCase):
         self.validData.setlist('memberships', ['administration', 'example'])
         self.invalidData = MultiValueDict()
         self.invalidData['wrong'] = 'wrong'
+        self.sessionFixture = self.registry.sessions.create(self.sessionKey)
 
     def tearDown(self):
         super(DomainObjectManipulatorTestCase, self).tearDown()
+        if self.sessionKey in self.registry.sessions:
+            del(self.registry.sessions[self.sessionKey])
         if self.fixtureName in self.registry.persons.getAll():
             person = self.registry.persons.getAll()[self.fixtureName]
             person.delete()
@@ -85,8 +90,9 @@ class TestDomainObjectManipulatorCreate(DomainObjectManipulatorTestCase):
         self.failUnlessEqual(person.fullname, self.validData['fullname'])
         self.failUnlessEqual(person.email, self.validData['email'])
         self.failUnlessEqual(person.role.getRegisterKeyValue(), self.validData['role'])
-        adminProject = self.registry.projects['administration']
-        self.failUnless(adminProject in person.memberships)
+        self.sessionFixture.person = person
+        self.sessionFixture.save()
+        self.failUnless(self.sessionKey in person.sessions)
 
 
 class TestDomainObjectManipulatorUpdate(DomainObjectManipulatorTestCase):
@@ -115,38 +121,42 @@ class TestDomainObjectManipulatorUpdate(DomainObjectManipulatorTestCase):
         self.failUnlessEqual(person.role.getRegisterKeyValue(), self.validData['role'])
 
     def testUpdateHasMany(self):
-        self.validData.setlist('memberships', ['example'])
-        self.manipulator.update(self.validData)
         person = self.registry.persons[self.fixtureName]
-        adminProject = self.registry.projects['administration']
-        self.failIf(adminProject in person.memberships)
+        self.failIf(self.sessionKey in person.sessions)
+        self.sessionFixture.person = person
+        self.sessionFixture.save()
+        self.failUnless(self.sessionKey in person.sessions)
+        self.validData.setlist('sessions', [''])
+        self.manipulator.update(self.validData)
+        self.failIf(self.sessionKey in person.sessions)
 
 
 class HasManyManipulatorTestCase(ManipulatorTestCase):
 
-    projectName = 'warandpeace'
+    sessionKey = 'sessiontestkey34234234234535634561345'
     personName = 'levin'
     roleName = 'Developer'
 
     def setUp(self):
-        super(HasManyManipulatorTestCase, self).setUp()
         self.person = self.registry.persons[self.personName]
+        super(HasManyManipulatorTestCase, self).setUp()
         self.validData = MultiValueDict()
         self.validData['person'] = self.personName
-        self.validData['role'] = self.roleName
+        self.validData['key'] = self.sessionKey
+        self.validData['lastVisited'] = ''
         self.invalidData = MultiValueDict()
-        self.invalidData['wrong'] = 'wrong'
+        self.invalidData['person'] = self.personName
+        self.invalidData['key'] = self.sessionKey
+        self.invalidData['lastVisited'] = 'letters'
+        self.sessionFixture = self.registry.sessions.create(self.sessionKey)
 
     def tearDown(self):
         super(HasManyManipulatorTestCase, self).tearDown()
-        if self.person in self.project.members:
-            membership = self.project.members[self.person]
-            membership.delete()
-            membership.purge()
+        if self.sessionKey in self.registry.sessions:
+            del(self.registry.sessions[self.sessionKey])
 
     def buildManipulator(self):
-        self.project = self.registry.projects[self.projectName]
-        return HasManyManipulator(objectRegister=self.project.members)
+        return HasManyManipulator(objectRegister=self.person.sessions)
 
 
 class TestHasManyManipulator(HasManyManipulatorTestCase):
@@ -160,3 +170,6 @@ class TestHasManyManipulator(HasManyManipulatorTestCase):
     def testDecodeHtml(self):
         self.manipulator.decodeHtml(self.validData)
 
+    def testCreate(self):
+        self.manipulator.create(self.validData)
+
