@@ -1,5 +1,5 @@
 import unittest
-from dm.view.basetest import ViewTestCase
+from dm.view.basetest import TestCase, ViewTestCase
 from dm.view.registry import RegistryView
 from dm.view.registry import RegistryListView
 from dm.view.registry import RegistrySearchView
@@ -47,7 +47,6 @@ class MockRegistryDeleteView(MockRegistryView, RegistryDeleteView):
 class RegistryViewTestCase(ViewTestCase):
     
     registryPath = 'persons'
-    requiredActionName = ''
     viewerName = 'admin'
 
     def createViewKwds(self):
@@ -56,21 +55,31 @@ class RegistryViewTestCase(ViewTestCase):
         return viewKwds
 
     def test_actionName(self):
-        self.failUnlessEqual(self.view.actionName, self.requiredActionName)
+        self.failUnlessEqual(self.view.actionName, self.actionName)
 
     def test_getViewPosition(self):
-        self.failUnlessEqual(self.view.getViewPosition(), "persons/list")
+        self.failUnlessEqual(self.view.getViewPosition(), self.viewPosition)
 
 
 class TestRegistryView(RegistryViewTestCase):
+
     viewClass = MockRegistryView
+    actionName = ''
+    viewPosition = 'persons/list'
+
 
 class TestRegistryListView(RegistryViewTestCase):
+
     viewClass = MockRegistryListView
+    actionName = 'list'
+    viewPosition = 'persons/list'
+
 
 class TestRegistrySearchView(RegistryViewTestCase):
 
     viewClass = MockRegistrySearchView
+    actionName = 'search'
+    viewPosition = 'persons/search'
     userQuery = 'admin'
 
     def initPost(self):
@@ -83,8 +92,8 @@ class TestRegistrySearchView(RegistryViewTestCase):
         self.failUnless(self.view.context['domainObjectList'])
         self.failUnlessEqual(self.view.userQuery, self.userQuery)
         self.failUnlessEqual(self.view.context['userQuery'], self.userQuery)
-        self.failUnlessEqual(self.view.context['resultsCount'], 1)
-        self.failUnlessEqual(self.view.context['isResultSingular'], True)
+        self.failUnlessEqual(self.view.context['objectCount'], 1)
+        self.failUnlessEqual(self.view.context['isCountSingle'], True)
     
     def test_searchManipulatedRegister(self):
         self.view.userQuery = 'adm'
@@ -104,11 +113,14 @@ class TestRegistrySearchView(RegistryViewTestCase):
         self.failUnlessEqual(results[0].name, 'visitor')
         self.view.userQuery = 'i'
         results = self.view.searchManipulatedRegister()
-        self.failUnlessEqual(len(results), 3)
+        self.failUnlessEqual(len(results), 3, [i.name for i in results])
+
 
 class TestRegistrySearchView2(RegistryViewTestCase):
 
     viewClass = MockRegistrySearchView
+    actionName = 'search'
+    viewPosition = 'persons/search'
     startsWith = 'ad'
 
     def initPost(self):
@@ -121,22 +133,30 @@ class TestRegistrySearchView2(RegistryViewTestCase):
         self.failUnless(self.view.context['domainObjectList'])
         self.failUnlessEqual(self.view.startsWith, self.startsWith)
         self.failUnlessEqual(self.view.context['startsWith'], self.startsWith)
-        self.failUnlessEqual(self.view.context['resultsCount'], 1)
-        self.failUnlessEqual(self.view.context['isResultSingular'], True)
+        self.failUnlessEqual(self.view.context['objectCount'], 1)
+        self.failUnlessEqual(self.view.context['isCountSingle'], True)
 
 
 class TestRegistryCreateView(RegistryViewTestCase):
     viewClass = MockRegistryCreateView
+    actionName = 'create'
+    viewPosition = 'persons/create'
 
 class TestRegistryReadView(RegistryViewTestCase):
     viewClass = MockRegistryReadView
+    actionName = 'read'
     registryPath = 'persons/admin'
+    viewPosition = 'persons/read'
 
 class TestRegistryUpdateView(RegistryViewTestCase):
     viewClass = MockRegistryUpdateView
+    actionName = 'update'
     registryPath = 'persons/admin'
+    viewPosition = 'persons/update'
 
 class TestRegistryDeleteView(RegistryViewTestCase):
     viewClass = MockRegistryDeleteView
+    actionName = 'delete'
     registryPath = 'persons/admin'
+    viewPosition = 'persons/delete'
 
